==> codemirror-form-customize-0.1.5.tgz: package/src/utils/request.js <==
import axios from 'axios'
import notification from 'ant-design-vue/es/notification'
const api = '/webroot'

// 创建 axios 实例
const service = axios.create({
  // baseURL: '/api', // api base_url
  baseURL: api,
  timeout: 6000, // 请求超时时间
  headers: {
    'Content-Type': 'application/json'
  }
})

const err = (error) => {
  if (error.response) {
    const data = error.response.data
    if (error.response.status === 403) {
      notification.error({
        message: 'Forbidden',
        description: data.message
      })
    }
    if (error.response.status === 401 && !(data.result && data.result.isLogin)) {
      notification.error({
        message: 'Unauthorized',
        description: 'Authorization verification failed'
      })
      // if (token) {
      //   store.dispatch('Logout').then(() => {
      //     setTimeout(() => {
      //       window.location.reload()
      //     }, 1500)
      //   })
      // }
    }
  }
  return Promise.reject(error)
}

// request interceptor
service.interceptors.request.use(config => {
// const token = Vue.ls.get(ACCESS_TOKEN);
  const token = 'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJleHAiOjE1OTk3MjYwNDUsImlhdCI6MTU5OTcyNDI0NSwidXNlcm5hbWUiOiJhZG1pbmlzdHJhdG9yIn0.D7QCVWAvHAHSbZ-Wh5f2uczVhqE0EBbAzi5e4MmcCzQ'
  if (token) {
    config.headers['access_token'] = token // 让每个请求携带自定义 token 请根据实际情况自行修改
  }
  return config
}, err)

// response interceptor
service.interceptors.response.use((response) => {
  return response.data
}, err)

export {
  service as axios
}
export default service

==> codemirror-form-customize-0.3.4.tgz: package/src/utils/request.js <==
import axios from 'axios'
import notification from 'ant-design-vue/es/notification'
const api = '/webroot'

// 创建 axios 实例
const service = axios.create({
  // baseURL: '/api', // api base_url
  baseURL: api,
  timeout: 6000, // 请求超时时间
  headers: {
    'Content-Type': 'application/json'
  }
})

const err = (error) => {
  if (error.response) {
    const data = error.response.data
    if (error.response.status === 403) {
      notification.error({
        message: 'Forbidden',
        description: data.message
      })
    }
    if (error.response.status === 401 && !(data.result && data.result.isLogin)) {
      notification.error({
        message: 'Unauthorized',
        description: 'Authorization verification failed'
      })
      // if (token) {
      //   store.dispatch('Logout').then(() => {
      //     setTimeout(() => {
      //       window.location.reload()
      //     }, 1500)
      //   })
      // }
    }
  }
  return Promise.reject(error)
}

// request interceptor
service.interceptors.request.use(config => {
// const token = Vue.ls.get(ACCESS_TOKEN);
  const token = 'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJleHAiOjE2MDEwOTMxMDUsImlhdCI6MTYwMTA5MTMwNSwidXNlcm5hbWUiOiJhZG1pbmlzdHJhdG9yIn0.fVhXwQBTMSbIE7Wg1M65AySmEaF-SZ-ijfE90VB7Bic'
  if (token) {
    config.headers['access_token'] = token // 让每个请求携带自定义 token 请根据实际情况自行修改
  }
  return config
}, err)

// response interceptor
service.interceptors.response.use((response) => {
  return response.data
}, err)

export {
  service as axios
}
export default service
